# pyrd

**pyrd** is an asynchronous library providing bindings for the Real-Debrid API. Premium account required for most endpoints.

# Usage

## Installation

```console
$ pip install pyrd
```

## Using the API

Every function has a docstring, and examples are provided in the [examples directory](https://github.com/itsnebulalol/pyrd/tree/main/examples).

# Credits

This project is inspired by [s-krilla/rd_api_py](https://github.com/s-krilla/rd_api_py). pyrd is intended to be a maintained, modern, asynchronous recreation of rd_api_py.
